<template>
    <AppLayout title="Clients">
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight"> Client Accounts
                <NavLink
                    class="ml-7 bg-gray-800 rounded-lg px-5 text-white font-semibold text-xs uppercase hover:bg-gray-200 active:bg-gray-900 focus:outline-none focus:border-gray-900 focus:ring focus:ring-gray-300 items-center"
                    :href="route('clients')" :active="route().current('clients')">
                    View Clients
                </NavLink>
            </h2>
        </template>
        <div>
            <div class="max-w-4xl mx-auto py-5 sm:px-6 mt-8 lg:px-8 mx-auto ">
                <SectionTitle>
                    <template #title>
                        Organisation Information
                    </template>
                </SectionTitle>
                <form>
                    <div class="border-2 rounded-xl px-6 py-6 mb-6 pb-6 justify-center bg-white rounded-xl shadow-xl ">
                        <div class="grid grid-cols- gap-3">
                            <div class="col-span-6 sm:col-span-4">
                                <InputLabel for="username" value="Organisation's username (login)"/>
                                <TextInput autofocus id="username" ref="username" v-model="form.username" type="text"
                                           class="mt-1 block w-full"
                                           autocomplete="org"/>
                                <InputError :message="form.errors.username" class="mt-2"/>
                            </div>
                            <div class="col-span-6 sm:col-span-4">
                                <InputLabel for="name" value="Organisation's name"/>
                                <TextInput id="name" ref="name" v-model="form.name" type="text" class="mt-1 block w-full"
                                           autocomplete="organisation"/>
                                <InputError :message="form.errors.name" class="mt-2"/>
                            </div>
                            <div class="col-span-6 sm:col-span-4">
                                <InputLabel for="email" value="Organisation's email"/>
                                <TextInput id="email" ref="email" v-model="form.email" type="text" class="mt-1 block w-full"
                                           autocomplete="email"/>
                                <InputError :message="form.errors.email" class="mt-2"/>
                            </div>
                            <div class="col-span-6 sm:col-span-4">
                                <InputLabel for="address" value="Organisation's address"/>
                                <TextInput id="address" ref="address" v-model="form.address" type="text"
                                           class="mt-1 block w-full"
                                           autocomplete="address"/>
                                <InputError :message="form.errors.address" class="mt-2"/>
                            </div>
                            <div class="col-span-6 sm:col-span-4">
                                <InputLabel for="contact" value="Organisation's contact"/>
                                <TextInput id="contact" ref="contact" v-model="form.contact" type="text"
                                           class="mt-1 block w-full"
                                           autocomplete="contact"/>
                                <InputError :message="form.errors.contact" class="mt-2"/>
                            </div>
                        </div>
                    </div>
                    <SectionTitle>

                        <template #title>
                            Reference Information
                        </template>
                    </SectionTitle>
                    <div class="border-2 px-6 py-6 pb-6 justify-center bg-white rounded-tr-xl rounded-tl-xl shadow-xl ">
                        <div class="col-span-6 sm:col-span-4">
                            <InputLabel for="ref_name" value="Reference's name"/>
                            <TextInput id="ref_name" ref="ref_name" v-model="form.ref_name" type="text"
                                       class="mt-1 block w-full"
                                       autocomplete="organisation"/>
                            <InputError :message="form.errors.ref_name" class="mt-2"/>
                        </div>
                        <div class="col-span-6 sm:col-span-4">
                            <InputLabel for="ref_email" value="Reference's email"/>
                            <TextInput id="ref_email" ref="ref_email" v-model="form.ref_email" type="text"
                                       class="mt-1 block w-full"
                                       autocomplete="ref_email"/>
                            <InputError :message="form.errors.ref_email" class="mt-2"/>
                        </div>
                        <div class="col-span-6 sm:col-span-4">
                            <InputLabel for="ref_address" value="Reference's address"/>
                            <TextInput id="ref_address" ref="ref_address" v-model="form.ref_address" type="text"
                                       class="mt-1 block w-full"
                                       autocomplete="ref_address"/>
                            <InputError :message="form.errors.ref_address" class="mt-2"/>
                        </div>
                        <div class="col-span-6 sm:col-span-4">
                            <InputLabel for="ref_contact" value="Reference's contact"/>
                            <TextInput id="ref_contact" ref="ref_contact" v-model="form.ref_contact" type="text"
                                       class="mt-1 block w-full"
                                       autocomplete="ref_contact"/>
                            <InputError :message="form.errors.ref_contact" class="mt-2"/>
                        </div>
                    </div>
                    <div

                        class="flex items-center justify-end px-4 py-3 bg-gray-50 text-right sm:px-6 shadow sm:rounded-bl-md sm:rounded-br-md">
                        <ActionMessage :on="form.recentlySuccessful" class="mr-3">
                            Saved.
                        </ActionMessage>

                        <ConfirmsPassword @confirmed="createClient">
                            <PrimaryButton type="button" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                                Save
                            </PrimaryButton>
                        </ConfirmsPassword>
                    </div>
                </form>
            </div>
        </div>
    </AppLayout>
</template>

<script>
import AppLayout from "@/Layouts/AppLayout.vue";
import {useForm} from '@inertiajs/inertia-vue3';
import ActionMessage from '@/Components/ActionMessage.vue';
import FormSection from '@/Components/FormSection.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import SectionTitle from "@/Components/SectionTitle.vue";
import NavLink from '@/Components/NavLink.vue';
import ConfirmsPassword from '@/Components/ConfirmsPassword.vue';

export default {
    name: "Client.Create",
    components: {
        SectionTitle,
        AppLayout,
        ActionMessage,
        FormSection,
        InputLabel,
        InputError,
        PrimaryButton,
        TextInput,
        NavLink, ConfirmsPassword
    },
    data() {
        return {
            clients: this.$page.props.clients,
            form: useForm({
                name: '',
                email: '',
                address: '',
                contact: '',

                ref_name: '',
                ref_email: '',
                ref_contact: '',
                ref_address: '',

                username: '',
                password: '',
            })
        }
    },
    methods: {
        createClient() {
            this.form.post(route('clients.store'), {
                errorBag: 'createClient',
                preserveScroll: true,
                onSuccess: () => this.form.reset(),
                onError: () => {
                    this.$refs[Object.keys(this.form.errors)[0]] && this.$refs[Object.keys(this.form.errors)[0]].focus()
                    /*if (this.form.errors.username) {
                        this.form.reset('username', 'name', 'email');
                        this.$refs['username'].focus();
                    }*/
                },
            });
        }
    }
}
</script>

<style scoped>

</style>
